Learn R Programming

collett (version 0.1.2)

tplant: Survival following kidney transplantation

Description

Survival following kidney transplantation

Usage

tplant

Arguments

Format

A data frame with 434 rows and 7 variables:

patient

integer patient id

donor

integer donoe id

time

integer survival time in days

status

integer event indicator (0=censored, 1=graft failure or death with a functioning graft)

age

integer patient age (years)

diabetes

integer diabetes status (0=absent, 1=present)

cit

double cold ischaemic time, the time in hours between retrieval of the kidney from the donor and the transplantation

Details

See Collett (2023)